myImageLib
==========

.. automodule:: myimagelib.myImageLib






   .. rubric:: File reading

   .. autosummary::
      :toctree: myImageLib

      dirrec
      readdata

   .. rubric:: Image processing

   .. autosummary::
       :toctree: myImageLib

       bpass
       to8bit
       match_hist
       matlab_style_gauss2D

   .. rubric:: Tools

   .. autosummary::
      :toctree: myImageLib

      bestcolor
      wowcolor
      show_progress
      gauss1
      xy_bin
      
   .. rubric:: corrTrack

   .. autosummary::
      :toctree: myImageLib

      normxcorr2
      FastPeakFind
      maxk
      minimal_peakfind
      track_spheres_dt


   .. rubric:: Classes

   .. autosummary::
      :toctree: myImageLib

      rawImage
